import pandas as pd
from ratelimit import *
from brandy._util import *
from brandy.core.crypto import CryptoDaily


@rate_limited(1)
def get_ohlcv(since=None, limit=10, market="KRW", exchange="Bithumb", coin="BTC"):
    """
        거래소 (exchange)에서 day부터 limit 개수의 coin OHLCV를 가져온다.          
        - See. https://www.cryptocompare.com/api/#-api-data-histoday-
        :param since: 조사할 날짜 "년-월-일" 형태의 문자열. 예) 2018-03-03 
        :param limit: 조회할 데이터의 수 / 최대 120
        :param market: 결제 화폐
        :param exchange: 거래소 이름 예) Bithumb, Korbit, Bitfnex  
        :param coin: 코인 이름 약어
        :return: (날짜, open, high, low, close, vlume) 리스트
        """
    timestamp = daystr_to_timestamp(since, offset=limit)
    response = CryptoDaily.get_price_list(timestamp, limit, market, exchange, coin)

    labels = ['day', 'open', 'high', 'low', 'close', 'volume']
    values = [(timestamp_to_daystr(x['time']), x['open'], x['high'], x['low'], x['close'], x['volumefrom'])
            for x in response['Data'][-limit:]]
    return pd.DataFrame.from_records(values, columns=labels)


@rate_limited(1)
def get_price(market="KRW", exchange="Bithumb", coin="BTC"):
    """
    거래소 (exchange)에서 최근 거래된 coin 가격을 가져온다.                  
    - See. https://www.cryptocompare.com/api/#-api-data-price-    
    :param market: 결제 화폐
    :param exchange: 거래소 이름 예) Bithumb, Korbit, Bitfnex: 
    :param coin: 코인 이름 약어
    :return: 코인의 종가 가격
    """
    response = CryptoDaily.get_price(market, exchange, coin)
    return response[market]


# def get_inc_ratio(coin, start, last):
#     price_start = CryptoDaily.get_price(day=start, coin=coin)
#     price_last = CryptoDaily.get_price(day=last, coin=coin)
#     delta = datetime.strptime(last, "%Y-%m-%d") - datetime.strptime(start, "%Y-%m-%d")
#     return (price_last - price_start) / price_last / delta.days


if __name__ == "__main__":
    # resp = get_price(market="KRW", exchange="Bithumb")
    # print(resp)
    #
    # resp = get_price(market="KRW", exchange="Korbit")
    # print(resp)
    #
    # resp = get_price(market="USD", exchange="Bitfinex")
    # print(resp)

    resp = get_ohlcv(coin="BTC", since="2018-01-10")
    print(resp)



from ._base import *


class CryptoDaily:
    @staticmethod
    @HttpMethod.get
    def get_price_list(timestamp, limit, market, exchange, coin):
        """
        거래소 (exchange)에서 day부터 limit 개수의 coin OHLCV를 가져온다.          
        - See. https://www.cryptocompare.com/api/#-api-data-histoday-
        :param timestamp: 조사할 날짜의 timestamp
        :param limit: 조회할 데이터의 수 
        :param market: 결제 화폐
        :param exchange: 거래소 이름 예) Bithumb, Korbit, Bitfnex  
        :param coin: 코인 이름 약어
        :return: Dictionary 형태의 OHLCV 데이터
                 예) https://min-api.cryptocompare.com/data/histoday?fsym=BTC&tsym=KRW&limit=10&e=Korbit
        """
        url = "https://min-api.cryptocompare.com/data/histoday"
        data = {
            "fsym": coin,
            "tsym": market,
            "limit": limit - 1,
            "e": exchange,
            "toTs": timestamp
        }
        return HttpParam(url=url, data=data)

    @staticmethod
    @HttpMethod.get
    def get_price(market, exchange, coin):
        """
        거래소 (exchange)에서 최근 거래된 coin 가격을 가져온다.                  
        - See. https://www.cryptocompare.com/api/#-api-data-price-
        :param day: 조사할 날짜 "년-월-일" 형태의 문자열. 예) 2018-03-03
        :param market: 결제 화폐
        :param exchange: 거래소 이름 예) Bithumb, Korbit, Bitfnex: 
        :param coin: 코인 이름 약어
        :return: 코인의 종가 가격
        """
        url = "https://min-api.cryptocompare.com/data/price"
        data = {
            "fsym": coin,
            "tsyms": market,
            "e": exchange
        }
        return HttpParam(url=url, data=data)



import time
import datetime


def daystr_to_timestamp(daystr, offset=0):
    if daystr is None:
        timestamp = time.time()
    else:
        target = datetime.datetime.strptime(daystr, "%Y-%m-%d") + datetime.timedelta(days=offset)
        timestamp = time.mktime(target.timetuple())
    return int(timestamp)


def timestamp_to_daystr(timestamp):
    dt = datetime.datetime.fromtimestamp(timestamp)
    return dt.strftime("%Y-%m-%d")


if __name__ == "__main__":
    timestamp = daystr_to_timestamp("2018-03-03", offset=1)
    print(timestamp)

    daystr = timestamp_to_daystr(timestamp)
    print(daystr)


# -*- coding: utf-8 -*-
from setuptools import setup, find_packages

with open('README') as f:
    readme = f.read()

setup(
    name='vericoin',
    version='0.1.0',
    description='암호화폐 Daily 가격 조회',
    long_description=readme,
    author='jonghun.yoo',
    author_email='jonghun.yoo@outlook.com',
    url='https://github.com/sharebook-kr/vericoin',
    keywords='coin cryptocurrency',
    license='GPL',
    packages=find_packages(exclude=[]),
)

